@@ -5,9 +5,17 @@
 use crate::prelude::*;
 
 def_subcontrol!(
-    docs: "",
+    docs: "
+
+
+        # Examples
+
+        ```no_run
+        // TODO
+        ```
+    ",
     ty: Combobox,
     handle: uiCombobox,
 );
 
-impl Combobox<'_> {}
+impl Combobox {}
