@@ -5,9 +5,17 @@
 use crate::prelude::*;
 
 def_subcontrol!(
-    docs: "",
+    docs: "
+
+
+        # Examples
+
+        ```no_run
+        // TODO
+        ```
+    ",
     ty: Form,
     handle: uiForm,
 );
 
-impl Form<'_> {}
+impl Form {}
