@@ -4,22 +4,34 @@
 
 use crate::prelude::*;
 
-impl<'ui> Ui<'ui> {
+impl Ui {
     /// Creates a new [`Grid`].
-    pub fn create_grid<'a>(&'a self) -> Result<&'a mut Grid<'ui>, crate::Error> {
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// // TODO
+    /// ```
+    pub fn create_grid(&self) -> Result<Grid, crate::Error> {
         call_libui_new_fn!(
             ui: self,
-            ui_lt: 'ui,
-            alloc: alloc_grid,
             fn: uiNewGrid() -> Grid,
         )
     }
 }
 
 def_subcontrol!(
-    docs: "",
+    docs: "
+
+
+        # Examples
+
+        ```no_run
+        // TODO
+        ```
+    ",
     ty: Grid,
     handle: uiGrid,
 );
 
-impl Grid<'_> {}
+impl Grid {}
