@@ -4,24 +4,36 @@
 
 use crate::prelude::*;
 
-impl<'ui> Ui<'ui> {
+impl Ui {
     /// Creates a new [`Image`].
-    pub fn create_image<'a>(
-        &'a self,
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// // TODO
+    /// ```
+    pub fn create_image(
+        &self,
         width: f64,
         height: f64,
-    ) -> Result<&'a mut Image<'ui>, crate::Error> {
+    ) -> Result<Image, crate::Error> {
         call_libui_new_fn!(
             ui: self,
-            ui_lt: 'ui,
-            alloc: alloc_image,
             fn: uiNewImage(width, height) -> Image,
         )
     }
 }
 
 def_subcontrol!(
-    docs: "",
+    docs: "
+
+
+        # Examples
+
+        ```no_run
+        // TODO
+        ```
+    ",
     ty: Image,
     handle: uiImage,
 );
@@ -34,7 +46,14 @@ pub struct Pixel {
     pub a: u8,
 }
 
-impl Image<'_> {
+impl Image {
+    ///
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// // TODO
+    /// ```
     pub fn append(&self, pixels: &mut [Pixel], width: u16, height: u16, byte_stride: u16) {
         unsafe {
             uiImageAppend(
